function Set-PdfPassword {
<#
.SYNOPSIS
Protects the PDF with a password
.PARAMETER SourceFile
Path to the SourceFile
.PARAMETER DestinationFile
Password for the file
.PARAMETER Password
Full path of the password protected PDF
.PARAMETER PdfSharpPath
Full path to the required PdfSharp library
.PARAMETER Force
Tries to force destination file and directory creation and deletion of source files, even when they are read-only
.PARAMETER
RemoveSourceFiles
Deletes the source files after PDF is merged
.EXAMPLE
Set-PdfPassword -SourceFile "C:\TEMP\test.pdf" -DestinationFile "C:\TEMP\protected_test.pdf" -Password "SECRET" -PdfSharpPath 'C:\ProgramData\coolOrange\powerJobs\Modules\PdfSharp-gdi.dll' -Force -RemoveSourceFiles
#>
param(
[Parameter(Mandatory=$true)]
[ValidateNotNullOrEmpty()]
[System.IO.FileInfo]$SourceFile,
[Parameter(Mandatory=$true)]
[ValidateNotNullOrEmpty()]
[System.IO.FileInfo]$DestinationFile,
[Parameter(Mandatory=$true)]
[ValidateNotNullOrEmpty()]
[string]$Password,
[Parameter(Mandatory=$true)]
[ValidateNotNullOrEmpty()]
$PdfSharpPath,
[switch]$Force,
[switch]$RemoveSourceFiles
)

    Write-Host ">> $($MyInvocation.MyCommand.Name) >>"

    if((Test-Path $PdfSharpPath) -eq $false) {
        throw "Could not find pdfsharp assembly at $($PdfSharpPath)"
    }
    Add-Type -LiteralPath $PdfSharpPath

    if((Test-Path $DestinationFile.FullName) -and $DestinationFile.IsReadOnly -and -not $Force) {
        throw "Destination file '$($DestinationFile.FullName)' is read only"
    }

    $document = [PdfSharp.Pdf.IO.PdfReader]::Open($SourceFile.FullName)
    $securitySettings = $document.SecuritySettings;
    
    # Set Password
    $securitySettings.UserPassword = $Password

    # Restrict some permissions
    $securitySettings.PermitAccessibilityExtractContent = $false;
    $securitySettings.PermitAnnotations = $false;
    $securitySettings.PermitAssembleDocument = $false;
    $securitySettings.PermitExtractContent = $false;
    $securitySettings.PermitFormsFill = $true;
    $securitySettings.PermitFullQualityPrint = $false;
    $securitySettings.PermitModifyDocument = $true;
    $securitySettings.PermitPrint = $false;

    Write-Host "Saving PDF"
    if((Test-Path $DestinationFile.FullName) -and $Force) { 
        Remove-Item $DestinationFile.FullName -Force 
    }
    $document.Save($DestinationFile.FullName)
}